@@ -308,7 +308,7 @@ class Acido(object):
                 print(bad(f'Error while erasing {group} and its instances. Maybe its already deleted?'))
         return
 
-    def save_output(self, command: list[str] = None):
+    def save_output(self, command: list = None):
         output = subprocess.check_output(command, shell=True)
         file, filename = self.blob_manager.upload(
             output
@@ -363,7 +363,7 @@ class Acido(object):
 
         return
 
-    def scan(self, command: list[str] = None, instance_num: int = 3, fleet_name: str = 'acido', interactive=False):
+    def scan(self, command: list = None, instance_num: int = 3, fleet_name: str = 'acido', interactive=False):
         response = {}
         if instance_num > 10:
             instance_num_groups = list(chunks(range(1, instance_num + 1), 10))
